# cnert/cli.py
# vim: ai et ts=4 sw=4 sts=4 ft=python fileencoding=utf-8

from typing import Optional

import typer

from . import __version__

app = typer.Typer()


def version_callback(value: bool):
    if value:
        typer.echo(__version__)
        raise typer.Exit()


@app.command()
def main(
    version: Optional[bool] = typer.Option(
        None, "--version", callback=version_callback
    ),
):
    typer.echo("42")



# tests/cnert/test_cli.py
# vim: ai et ts=4 sw=4 sts=4 ft=python fileencoding=utf-8

from typer.testing import CliRunner

from cnert import __version__
from cnert.cli import app

runner = CliRunner()


def test_cli_without_args_options():
    result = runner.invoke(app)
    assert result.exit_code == 0
    assert "42" in result.stdout


def test_cli_with_option_version():
    result = runner.invoke(app, ["--version"])
    assert result.exit_code == 0
    assert result.stdout == f"{__version__}\n"



# cnert/__init__.py
# vim: ai et ts=4 sw=4 sts=4 ft=python fileencoding=utf-8

"""Top-level package for cnert."""

__author__ = """Maarten"""
__email__ = 'maarten@example.com'

# Version set by setuptools_scm
try:
    from importlib.metadata import version
except ImportError:
    # Python version < 3.8
    from pkg_resources import get_distribution

    __version__ = get_distribution('cnert').version
else:
    __version__ = version('cnert')
